| all.equal.integer64 | R Documentation |
A utility to compare integer64 objects 'x' and 'y' testing for
‘near equality’, see all.equal().
## S3 method for class 'integer64'
all.equal(
target,
current,
tolerance = sqrt(.Machine$double.eps),
scale = NULL,
countEQ = FALSE,
formatFUN = function(err, what) format(err),
...,
check.attributes = TRUE
)
target |
a vector of 'integer64' or an object that can be coerced
with |
current |
a vector of 'integer64' or an object that can be coerced
with |
tolerance |
numeric > 0. Differences smaller than |
scale |
|
countEQ |
logical indicating if the |
formatFUN |
a |
... |
further arguments are ignored |
check.attributes |
logical indicating if the |
In all.equal.numeric() the type integer is treated as a proper subset
of double i.e. does not complain about comparing integer with double.
Following this logic all.equal.integer64 treats integer as a proper
subset of integer64 and does not complain about comparing integer with
integer64. double also compares without warning as long as the values
are within lim.integer64(), if double are bigger all.equal.integer64
complains about the all.equal.integer64 overflow warning. For further
details see all.equal().
Either ‘TRUE’ (‘NULL’ for ‘attr.all.equal’) or a vector of ‘mode’ ‘"character"’ describing the differences between ‘target’ and ‘current’.
all.equal() only dispatches to this method if the first argument is integer64,
calling all.equal() with a non-integer64 first and a integer64 second argument
gives undefined behavior!
all.equal()
all.equal(as.integer64(1:10), as.integer64(0:9))
all.equal(as.integer64(1:10), as.integer(1:10))
all.equal(as.integer64(1:10), as.double(1:10))
all.equal(as.integer64(1), as.double(1e300))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.