Learn R Programming

bit64 (version 4.8.4)

duplicated.integer64: Determine Duplicate Elements of integer64

Description

duplicated() determines which elements of a vector or data frame are duplicates of elements with smaller subscripts, and returns a logical vector indicating which elements (rows) are duplicates.

Usage

# S3 method for integer64
duplicated(x, incomparables = FALSE, nunique = NULL, method = NULL, ...)

Arguments

Value

duplicated(): a logical vector of the same length as x.

Details

This function automatically chooses from several low-level functions considering the size of x and the availability of a cache.

Suitable methods are

  • hashdup (hashing)

  • sortorderdup (fast ordering)

  • orderdup (memory saving ordering).

See Also

duplicated(), unique.integer64()

Examples

Run this code
x <- as.integer64(sample(c(rep(NA, 9), 1:9), 32, TRUE))
duplicated(x)

stopifnot(identical(duplicated(x),  duplicated(as.integer(x))))

Run the code above in your browser using DataLab