extract.replace.integer64: Extract or Replace Parts of an integer64 vector

extract.replace.integer64R Documentation

Extract or Replace Parts of an integer64 vector

Description

Methods to extract and replace parts of an integer64 vector.

Usage

## S3 method for class 'integer64'
x[i, j, ..., drop = TRUE]

## S3 replacement method for class 'integer64'
x[...] <- value

## S3 method for class 'integer64'
x[[...]]

## S3 replacement method for class 'integer64'
x[[...]] <- value

Arguments

x

an atomic vector

i, j

indices specifying elements to extract

...

further arguments to the NextMethod()

drop

relevant for matrices and arrays. If TRUE the result is coerced to the lowest possible dimension.

value

an atomic vector with values to be assigned

Value

A vector, matrix, array or scalar of class 'integer64'

Note

You should not subscript non-existing elements and not use NAs as subscripts. The current implementation returns 9218868437227407266 instead of NA.

See Also

[ integer64()

Examples

  as.integer64(1:12)[1:3]
  x <- matrix(as.integer64(1:12), nrow = 3L)
  x
  x[]
  x[, 2:3]

bit64 documentation built on April 21, 2026, 9:06 a.m.