| is.sorted.integer64 | R Documentation |
These methods are packaged here for methods in packages bit64 and ff.
## S3 method for class 'integer64'
na.count(x, ...)
## S3 method for class 'integer64'
nvalid(x, ...)
## S3 method for class 'integer64'
is.sorted(x, ...)
## S3 method for class 'integer64'
nunique(x, ...)
## S3 method for class 'integer64'
nties(x, ...)
x |
some object |
... |
ignored |
All these functions benefit from a sortcache(), ordercache() or
sortordercache(). na.count(), nvalid() and nunique() also
benefit from a hashcache().
is.sorted returns a logical scalar, the other methods return an integer scalar.
na.count(integer64): returns the number of NAs
nvalid(integer64): returns the number of valid data points,
usually length() minus na.count.
is.sorted(integer64): checks for sortedness of x (NAs sorted first)
nunique(integer64): returns the number of unique values
nties(integer64): returns the number of tied values.
If a cache() exists but the desired value is not cached, then these
functions will store their result in the cache. We do not consider this
a relevant side-effect, since these small cache results do not have a
relevant memory footprint.
cache() for caching functions and sortordercache() for functions creating big caches
x = as.integer64(sample(c(rep(NA, 9), 1:9), 32, TRUE))
length(x)
bit::na.count(x)
bit::nvalid(x)
bit::nunique(x)
bit::nties(x)
table(x)
x
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.