| ops64 | R Documentation |
Binary operators for integer64 vectors.
binattr(e1, e2)
## S3 method for class 'integer64'
e1 + e2
## S3 method for class 'integer64'
e1 - e2
## S3 method for class 'integer64'
e1 %/% e2
## S3 method for class 'integer64'
e1 %% e2
## S3 method for class 'integer64'
e1 * e2
## S3 method for class 'integer64'
e1 ^ e2
## S3 method for class 'integer64'
e1 / e2
## S3 method for class 'integer64'
e1 == e2
## S3 method for class 'integer64'
e1 != e2
## S3 method for class 'integer64'
e1 < e2
## S3 method for class 'integer64'
e1 <= e2
## S3 method for class 'integer64'
e1 > e2
## S3 method for class 'integer64'
e1 >= e2
## S3 method for class 'integer64'
e1 & e2
## S3 method for class 'integer64'
e1 | e2
## S3 method for class 'integer64'
!x
e1, e2, x |
numeric or complex vectors or objects which can be coerced to such, or other objects for which methods have been written for - especially 'integer64' vectors. |
&, |, !, !=, ==, <, <=, >, >= return a logical vector
/ returns a double vector
+, -, *, %/%, %%, ^ return a vector of class 'integer64' or different class depending on the operands
integer64()
as.integer64(1:12) - 1
options(integer64_semantics="new")
d <- 2.5
i <- as.integer64(5)
d/i # new 0.5
d*i # new 13
i*d # new 13
options(integer64_semantics="old")
d/i # old: 0.4
d*i # old: 10
i*d # old: 13
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.