| plusclass | R Documentation |
Maintaining integer64 S3 class attribute.
minusclass(class, whichclass)
class |
NULL or a character vector of class attributes |
whichclass |
the (single) class name to add or remove from the class vector |
NULL or a character vector of class attributes
oldClass() integer64()
plusclass("inheritingclass", "integer64")
minusclass(c("inheritingclass", "integer64"), "integer64")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.