| extract.replace.integer64 | R Documentation |
Methods to extract and replace parts of an integer64 vector.
## S3 method for class 'integer64'
x[i, j, ..., drop = TRUE]
## S3 replacement method for class 'integer64'
x[...] <- value
## S3 method for class 'integer64'
x[[...]]
## S3 replacement method for class 'integer64'
x[[...]] <- value
x |
an atomic vector |
i, j |
indices specifying elements to extract |
... |
further arguments to the |
drop |
relevant for matrices and arrays. If TRUE the result is coerced to the lowest possible dimension. |
value |
an atomic vector with values to be assigned |
A vector, matrix, array or scalar of class 'integer64'
You should not subscript non-existing elements and not use NAs as subscripts.
The current implementation returns 9218868437227407266 instead of NA.
[ integer64()
as.integer64(1:12)[1:3]
x <- matrix(as.integer64(1:12), nrow = 3L)
x
x[]
x[, 2:3]
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.