Learn R Programming

bit64 (version 4.8.6)

extract.replace.integer64: Extract or Replace Parts of an integer64 vector

Description

Methods to extract and replace parts of an integer64 vector.

Usage

# S3 method for integer64
[(x, i, j, ..., drop = TRUE)

# S3 method for integer64 [(x, ...) <- value

# S3 method for integer64 [[(x, ...)

# S3 method for integer64 [[(x, ...) <- value

Value

A vector, matrix, array or scalar of class 'integer64'

Arguments

x

an atomic vector

i, j

indices specifying elements to extract

...

further arguments to the NextMethod()

drop

relevant for matrices and arrays. If TRUE the result is coerced to the lowest possible dimension.

value

an atomic vector with values to be assigned

See Also

[ integer64()

Examples

Run this code
  as.integer64(1:12)[1:3]
  x <- matrix(as.integer64(1:12), nrow = 3L)
  x
  x[]
  x[, 2:3]

Run the code above in your browser using DataLab