Learn R Programming

bit64 (version 4.8.4)

is.sorted.integer64: Small cache access methods

Description

These methods are packaged here for methods in packages bit64 and ff.

Usage

# S3 method for integer64
na.count(x, ...)

# S3 method for integer64 nvalid(x, ...)

# S3 method for integer64 is.sorted(x, ...)

# S3 method for integer64 nunique(x, ...)

# S3 method for integer64 nties(x, ...)

Arguments

Value

is.sorted returns a logical scalar, the other methods return an integer scalar.

Details

All these functions benefit from a sortcache(), ordercache() or sortordercache(). na.count(), nvalid() and nunique() also benefit from a hashcache().

See Also

cache() for caching functions and sortordercache() for functions creating big caches

Examples

Run this code
 x = as.integer64(sample(c(rep(NA, 9), 1:9), 32, TRUE))
 length(x)
 bit::na.count(x)
 bit::nvalid(x)
 bit::nunique(x)
 bit::nties(x)
 table(x)
 x

Run the code above in your browser using DataLab