powered by
These methods are packaged here for methods in packages bit64 and ff.
bit64
ff
# S3 method for integer64 na.count(x, ...)# S3 method for integer64 nvalid(x, ...)# S3 method for integer64 is.sorted(x, ...)# S3 method for integer64 nunique(x, ...)# S3 method for integer64 nties(x, ...)
# S3 method for integer64 nvalid(x, ...)
# S3 method for integer64 is.sorted(x, ...)
# S3 method for integer64 nunique(x, ...)
# S3 method for integer64 nties(x, ...)
is.sorted returns a logical scalar, the other methods return an integer scalar.
is.sorted
All these functions benefit from a sortcache(), ordercache() or sortordercache(). na.count(), nvalid() and nunique() also benefit from a hashcache().
sortcache()
ordercache()
sortordercache()
na.count()
nvalid()
nunique()
hashcache()
cache() for caching functions and sortordercache() for functions creating big caches
cache()
x = as.integer64(sample(c(rep(NA, 9), 1:9), 32, TRUE)) length(x) bit::na.count(x) bit::nvalid(x) bit::nunique(x) bit::nties(x) table(x) x
Run the code above in your browser using DataLab