| keypos | R Documentation |
keypos returns the positions of the (fact table) elements that participate
in their sorted unique subset (dimension table)
keypos(x, ...)
## S3 method for class 'integer64'
keypos(x, method = NULL, ...)
x |
a vector or a data frame or an array or |
... |
ignored |
method |
NULL for automatic method selection or a suitable low-level method, see details |
NAs are sorted first in the dimension table, see ramorder.integer64().
This function automatically chooses from several low-level functions
considering the size of x and the availability of a cache.
Suitable methods are
sortorderkey (fast ordering)
orderkey (memory saving ordering).
an integer vector of the same length as x containing positions
relative to sort(unique(x), na.last=FALSE)
unique.integer64() for the unique subset and match.integer64()
for finding positions in a different vector.
x <- as.integer64(sample(c(rep(NA, 9), 1:9), 32, TRUE))
keypos(x)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.