seq.integer64: Generating sequence of integer64 values
Description
Generating sequence of integer64 values
Usage
# S3 method for integer64
seq(
from = NULL,
to = NULL,
by = NULL,
length.out = NULL,
along.with = NULL,
...
)
Value
An integer64 vector with the generated sequence
Arguments
from
integer64 scalar (in order to dispatch the integer64 method of seq())
to
scalar
by
scalar
length.out
scalar
along.with
scalar
...
ignored
Details
seq.integer64 coerces its arguments from, to, and by to integer64. Consistency
with seq() is typically maintained, though results may differ when mixing integer64 and
double inputs, for the same reason that any arithmetic with these mixed types can be
ambiguous. Whereas seq(1L, 10L, length.out=8L) can back up to double storage to give an
exact result, this not possible for generic inputs seq(i64, dbl, length.out=n).