Learn R Programming

bit64 (version 4.8.4)

seq.integer64: Generating sequence of integer64 values

Description

Generating sequence of integer64 values

Usage

# S3 method for integer64
seq(
  from = NULL,
  to = NULL,
  by = NULL,
  length.out = NULL,
  along.with = NULL,
  ...
)

Arguments

Value

An integer64 vector with the generated sequence

Details

seq.integer64 coerces its arguments from, to, and by to integer64. Consistency with seq() is typically maintained, though results may differ when mixing integer64 and double inputs, for the same reason that any arithmetic with these mixed types can be ambiguous. Whereas seq(1L, 10L, length.out=8L) can back up to double storage to give an exact result, this not possible for generic inputs seq(i64, dbl, length.out=n).

See Also

c.integer64() rep.integer64() as.data.frame.integer64() integer64()

Examples

Run this code
seq(as.integer64(1), 12, 2)
seq(as.integer64(1), by=2, length.out=6)

# truncation rules
seq(as.integer64(1), 10, by=1.5)
seq(as.integer64(1), 10, length.out=5)

Run the code above in your browser using DataLab