Performs set union, intersection, (asymmetric!) difference, equality and membership on two vectors.
As soon as an integer64 vector is involved, the operations are performed using integer64 semantics. Otherwise
the base package functions are called.
Usage
union(x, y)
intersect(x, y)
setequal(x, y)
setdiff(x, y)
is.element(el, set)
Value
For union, a vector of a common mode or class.
For intersect, a vector of a common mode or class, or NULL if x or y is NULL.
For setdiff, a vector of the same mode or class as x.
A logical scalar for setequal and a logical of the same length as x for is.element.
Arguments
x, y, el, set
vectors (of the same mode) containing a sequence
of items (conceptually) with no duplicated values.